@@ -622,6 +622,8 @@ class Client:
         recursive: bool = False,
         limit_from: int = 0,
         limit_to: int = 2000,
+        flat_list: bool = False,
+        only_published: bool = False,
     ) -> List[Dict]:
         """
         Return the user's collections under the parent collection
@@ -650,7 +652,10 @@ class Client:
         ]
         ```
         """
-        return self.__call("collections", [parent_id, recursive, limit_from, limit_to])
+        return self.__call(
+            "collections",
+            [parent_id, recursive, limit_from, limit_to, flat_list, only_published],
+        )
 
     def deactivate_rpc_access(self, user_name: str, api_key: str) -> bool:
         """
